import numpy as np
from scipy.interpolate import interp1d
from scipy.optimize import minimize

def min_fn_rsas(x, alt_m, rad_meas, rad_ret):
    rad_meas_shift = np.exp(interp1d(alt_m, np.log(rad_meas), axis=0, bounds_error=False)(alt_m+x))

    low_alt_idx = (alt_m > 18500) & (alt_m < 22500)
    high_alt_idx = (alt_m > 30000) & (alt_m < 36500)

    y = (np.nanmean(rad_meas_shift[low_alt_idx])/np.nanmean(rad_meas_shift[high_alt_idx])) - (np.nanmean(rad_ret[low_alt_idx])/np.nanmean(rad_ret[high_alt_idx]))

    return np.linalg.norm(y)

def rsas_shift(alt_m, rad_meas, rad_ret):
    min_results = minimize(min_fn_rsas, 0, args=(alt_m, rad_meas, rad_ret), method='L-BFGS-B', bounds=[(-4000, 6000)])

    return min_results